import { jsxs as _jsxs, jsx as _jsx } from "react/jsx-runtime";
import Menu from "@mui/material/Menu";
import mergeWith from "lodash/mergeWith";
import { useContext, useState } from "react";
import { FormDataContext } from "../../context/FormData";
import * as formModalStyles from "../../styles/formControl.module.scss";
import Input from "../Input";
import { StyledDateRangeGroupContainer, Styledlabel, } from "./DateRangeGroup.styles";
import CalendarModal from "./components/CalendarModal";
const DateRangeGroup = ({ controlProps, ...props }) => {
    const { id, control, objectPathId } = props;
    const { displayName, controls } = control;
    const [anchorEl, setAnchorEl] = useState(null);
    const open = Boolean(anchorEl);
    const currObjectPathId = objectPathId || id;
    const { from, to } = controls;
    const { updateControl } = useContext(FormDataContext);
    const DateToString = (date) => {
        const year = date.toLocaleString("default", { year: "numeric" });
        const month = date.toLocaleString("default", { month: "2-digit" });
        const day = date.toLocaleString("default", { day: "2-digit" });
        return year + "-" + month + "-" + day;
    };
    const fromControlConfig = {
        id,
        objectPathId: `${currObjectPathId}.controls.from`,
        control: from,
        hasClearButton: true,
    };
    const handleFromInputChange = (newProperties, customizer) => {
        updateControl(fromControlConfig.objectPathId || id, mergeWith({}, fromControlConfig.control, newProperties, customizer));
    };
    const toControlConfig = {
        id,
        objectPathId: `${currObjectPathId}.controls.to`,
        control: to,
        hasClearButton: true,
    };
    const isRequired = fromControlConfig.control?.required || toControlConfig.control?.required;
    const handleToInputChange = (newProperties, customizer) => {
        updateControl(toControlConfig.objectPathId || id, mergeWith({}, toControlConfig.control, newProperties, customizer));
    };
    const handleDateChange = (date, keepModalState) => {
        handleFromInputChange({ value: DateToString(date.startDate) });
        handleToInputChange({ value: DateToString(date.endDate) });
        !keepModalState && setAnchorEl(null);
    };
    const handleCalendarOpen = (e) => {
        e.preventDefault();
        setAnchorEl(e.currentTarget);
    };
    const handleClearFromInput = () => {
        handleFromInputChange({ value: "" });
    };
    const handleClearToInput = () => {
        handleToInputChange({ value: "" });
    };
    const calendarModalConfig = {
        handleDateChange,
        from: fromControlConfig.control.value,
        to: toControlConfig.control.value,
    };
    const controlWrapperStyle = controlProps?.controlWrapperProps?.style ?? {};
    const controlWrapperLabelStyle = controlProps?.controlWrapperProps?.label?.style ?? {};
    const controlWrapperContainerStyle = controlProps?.controlWrapperProps?.container?.style ?? {};
    return (_jsxs(StyledDateRangeGroupContainer, { "data-testid": "dateRangeGroup__Container", style: controlWrapperStyle, children: [_jsxs(Styledlabel, { "data-testid": "dateRangeGroup__displayName", style: controlWrapperLabelStyle, children: [displayName, isRequired && " *"] }), _jsxs("div", { className: formModalStyles.daterangequerycontainer, style: controlWrapperContainerStyle, children: [_jsx(Input, { controlProps: controlProps, "data-testid": "dateRangeGroup__inputFrom", onClearCallback: handleClearFromInput, onClick: handleCalendarOpen, onChangeValue: handleFromInputChange, ...fromControlConfig }), _jsx(Input, { controlProps: controlProps, "data-testid": "dateRangeGroup__inputTo", onClearCallback: handleClearToInput, onClick: handleCalendarOpen, onChangeValue: handleToInputChange, ...toControlConfig }), _jsx(Menu, { anchorEl: anchorEl, open: open, onClose: () => setAnchorEl(null), anchorOrigin: { vertical: "bottom", horizontal: "left" }, "data-testid": "dateRangeGroup__calendarModal", children: _jsx(CalendarModal, { ...calendarModalConfig }) })] })] }));
};
export default DateRangeGroup;
//# sourceMappingURL=DateRangeGroup.js.map