import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { ThemeProvider, createTheme } from "@mui/material";
import cx from "classnames";
import React, { forwardRef, useContext, useEffect, useRef, useState, } from "react";
import { FormDataContext, FormDataProvider } from "../../context/FormData";
import Menu from "../../ui/menu";
import useMenu from "../../ui/menu/hooks/useMenu";
import FormFooter from "../FormFooter/";
import QueryControl from "../QueryControl";
import * as styles from "./FormBuilder.module.scss";
import extractFormControlValues from "./utils/extractFormControlValues";
import jsonToUrlEncoded from "./utils/jsonToUrlEncoded";
const FormBuilder = ({ config, controlProps, fileUploaderConfig, iconType, state, resolveUrl, onSubmit, postGenAiMessage, }) => {
    const { items, error, method } = config;
    const [formError, setFormError] = useState(error?.message);
    const [formState, setFormState] = useState(state || "");
    const [formSubmitted, setFormSubmitted] = useState(false);
    useEffect(() => {
        //* Reset formSubmitted when items change, because the form submission is async.
        //* This useEffect prevents the race condition where formSubmitted is triggered before items are updated.
        if (formSubmitted)
            setFormSubmitted(false);
    }, [items]);
    const formRef = useRef(null);
    const toggleFormSubmitted = () => setFormSubmitted(true);
    if (!config) {
        console.log("form config missing");
        return;
    }
    if (!items) {
        console.log("Items have to be defined in form config");
    }
    const onSubmitForm = async (controls) => {
        if (!formRef.current.checkValidity()) {
            return;
        }
        setFormState("processing");
        const formValues = extractFormControlValues(controls);
        const urlEncodedFormValues = jsonToUrlEncoded(formValues);
        onSubmit(urlEncodedFormValues, formValues)
            .then(() => {
            setFormState("success");
            toggleFormSubmitted();
        })
            .catch((error) => {
            console.error("error submitting form", error);
            setFormError(`${error.message}`);
            setFormState("error");
            toggleFormSubmitted();
        });
    };
    return (_jsx(FormDataProvider, { controls: items, fileUploaderConfig: fileUploaderConfig, resolveUrl: resolveUrl, postGenAiMessage: postGenAiMessage, children: _jsxs(ThemeProvider, { theme: createTheme({
                components: {
                    MuiPaper: {
                        styleOverrides: {
                            root: {
                                fontFamily: controlProps?.formProps?.style?.fontFamily || "Roboto",
                            },
                        },
                    },
                },
            }), children: [_jsx(Form, { method: method, ref: formRef, state: formState, controlProps: controlProps, formSubmitted: formSubmitted }), _jsx(FormFooter, { controlProps: controlProps, error: formError, iconType: iconType, loading: formState === "processing", onSubmit: onSubmitForm })] }) }));
};
export const Form = forwardRef(({ state, method, formSubmitted, controlProps }, ref) => {
    const { formControls, isExpertMode } = useContext(FormDataContext);
    const { activeFormControls, activeMenuItemIndex, controlGroups, hasSubmenu, menuItems, setActiveMenuItemIndex, } = useMenu(formControls, formSubmitted, isExpertMode);
    return (_jsxs("form", { ref: ref, className: cx(styles["form-builder-container"], { [styles.hasSubmenu]: hasSubmenu }, state), id: "form-horizontal xhtmlInstantForm", "data-testid": "form-horizontal xhtmlInstantForm", role: "form", method: method, style: controlProps?.formProps?.style, onSubmit: (e) => e.preventDefault(), children: [hasSubmenu && (_jsx(Menu, { menuItems: menuItems, activeMenuItemIndex: activeMenuItemIndex, onActiveMenuItemIndex: setActiveMenuItemIndex, children: controlGroups &&
                    activeFormControls &&
                    Object.entries(activeFormControls).map(([key, value]) => (_jsx(React.Fragment, { children: _jsx(QueryControl, { formControl: value, id: key, controlProps: controlProps }, key) }, key))) })), !hasSubmenu && (_jsx(_Fragment, { children: formControls &&
                    Object.entries(formControls).map(([key, value]) => (_jsx(React.Fragment, { children: _jsx(QueryControl, { formControl: value, id: key, controlProps: controlProps }, key) }, key))) }))] }));
});
Form.displayName = "Form";
export default FormBuilder;
//# sourceMappingURL=FormBuilder.js.map