import { convert } from "html-to-text";
import getSelectedOption from "../../../Select/utils/getSelectedOption";
const extractFormControlValues = (controls) => {
    const formState = {};
    controls &&
        Object.entries(controls)?.forEach(([key, control]) => {
            const formControl = control.control;
            const notListOrGroup = formControl !== "list" && formControl !== "group";
            const isTextarea = formControl === "textarea";
            const textareaEditorType = control?.["custom-attributes"]?.editor;
            const textareaRichtext = isTextarea && textareaEditorType === "richtext";
            const isSelect = formControl === "select";
            if (formControl === "list") {
                const listControls = control.items
                    ?.map((item) => extractFormControlValues(item))
                    .filter(Boolean);
                if (listControls?.length > 0)
                    formState[key] = listControls;
            }
            if (formControl === "group") {
                const groupControls = extractFormControlValues(control.controls);
                if (Object.entries(groupControls)?.length > 0) {
                    formState[key] = groupControls;
                }
            }
            if (isTextarea) {
                // get textarea attributes
                let textareaValue = control.value;
                // check if html value is empty (can be <h1></h1>)
                if (textareaRichtext) {
                    const trimedValue = convert(textareaValue);
                    if (trimedValue.trim().length <= 0) {
                        textareaValue = undefined;
                    }
                }
                formState[key] = textareaValue;
            }
            // get selected value from select because select control is possible not rendered because of sub menu component
            if (isSelect && !control?.value) {
                const selectDefaultValue = getSelectedOption(control.options, "");
                formState[key] = selectDefaultValue?.value;
            }
            if (notListOrGroup && control.value && !isTextarea) {
                formState[key] = control.value;
            }
        });
    return formState;
};
export default extractFormControlValues;
//# sourceMappingURL=extractFormControlValues.js.map