import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import AddIcon from "@mui/icons-material/Add";
import SaveIcon from "@mui/icons-material/Save";
import { FaSyncAlt } from "@react-icons/all-files/fa/FaSyncAlt";
import Button from "@mui/material/Button";
import FormControlLabel from "@mui/material/FormControlLabel";
import capitalize from "lodash/capitalize";
import { useContext } from "react";
import { FormDataContext } from "../../context/FormData";
import ErrorState from "../states/error";
import * as styles from "./FormFooter.module.scss";
import { CustomSwitch } from "./components/Switch";
const icon = {
    add: _jsx(AddIcon, { "data-testid": "formfooter__add-icon" }),
    save: _jsx(SaveIcon, { "data-testid": "formfooter__save-icon" }),
    update: _jsx(FaSyncAlt, { size: 14, "data-testid": "formfooter__update-icon" }),
};
const FormFooter = ({ controlProps, error, iconType, loading, onSubmit, }) => {
    const { formControls, isExpertMode, hasExpertMode, toggleExpertMode } = useContext(FormDataContext);
    const footerIcon = iconType && icon[iconType.toLowerCase()];
    const buttonText = (iconType && capitalize(iconType)) || "Add";
    const footerStyle = controlProps?.footerProps?.style ?? {};
    const footerContainerStyle = controlProps?.footerProps?.container?.style ?? {};
    const footerSubmitButtonContainerStyle = controlProps?.footerProps?.submitButtonContainer?.style ?? {};
    const footerSubmitButtonStyle = controlProps?.footerProps?.submitButton?.sx ?? {};
    return (_jsxs("div", { "data-testid": "form-footer-container", className: styles["form-footer-container"], style: footerStyle, children: [error && (_jsx("div", { className: styles.notificationContainer, children: _jsx(ErrorState, { error: error }) })), _jsxs("div", { className: styles.controlsContainer, style: footerContainerStyle, children: [hasExpertMode ? (_jsx(FormControlLabel, { "data-testid": "formfooter__expert-mode", control: _jsx(CustomSwitch, { checked: isExpertMode, onChange: toggleExpertMode }), label: "Expert Mode", sx: {
                            color: "rgba(0,0,0,.54)",
                            marginBottom: 0,
                            input: {
                                marginTop: 0,
                            },
                            ".MuiTypography-root": {
                                fontSize: 12,
                            },
                        } })) : (_jsx("div", {})), _jsxs("div", { className: styles["submit-container"], style: footerSubmitButtonContainerStyle, children: [_jsx("span", { className: styles["required-message"], children: "* Please fill in all required fields" }), _jsx(Button, { "data-testid": "formfooter__submit", id: "submit-button", variant: "contained", type: "submit", form: "form-horizontal xhtmlInstantForm", onClick: () => onSubmit(formControls), sx: {
                                    backgroundColor: "#4A96D2",
                                    boxShadow: "none",
                                    "&:hover": {
                                        backgroundColor: "#0B5BA6",
                                        boxShadow: "none",
                                    },
                                    ...footerSubmitButtonStyle,
                                }, endIcon: loading ? (_jsx("svg", { className: `${styles["run-button__spinner"]} run-button__spinner`, "data-testid": "formfooter__loading-icon", xmlns: "http://www.w3.org/2000/svg", width: "21.076", height: "20.31", viewBox: "0 0 21.076 20.31", children: _jsxs("g", { id: "Gruppe_272", "data-name": "Gruppe 272", transform: "translate(-269.58 -82.717)", children: [_jsx("path", { id: "Pfad_338", "data-name": "Pfad 338", d: "M278.934,84.754l3.514-2.03v4.06l-3.514,2.03Z", transform: "translate(-5.841 -0.004)", fill: "#fff" }), _jsx("path", { id: "Pfad_339", "data-name": "Pfad 339", d: "M288.29,86.784v-4.06l3.514,2.03v4.06Z", transform: "translate(-11.683 -0.004)", fill: "#f0f0f0" }), _jsx("path", { id: "Pfad_340", "data-name": "Pfad 340", d: "M282.45,119.233v-4.06l-3.514,2.03v4.06Z", transform: "translate(-5.842 -20.266)", fill: "#f0f0f0" }), _jsx("path", { id: "Pfad_341", "data-name": "Pfad 341", d: "M285.963,128.014l-3.515-2.03-3.514,2.03,3.514,2.03Z", transform: "translate(-5.841 -27.017)", fill: "#fff" }), _jsx("path", { id: "Pfad_342", "data-name": "Pfad 342", d: "M297.625,124.639l3.514,2.03v-4.06l-3.514-2.03Z", transform: "translate(-17.513 -23.642)", fill: "#fff" }), _jsx("path", { id: "Pfad_343", "data-name": "Pfad 343", d: "M306.981,122.609v4.06l3.514-2.03v-4.06Z", transform: "translate(-23.355 -23.642)", fill: "#f0f0f0" }), _jsx("path", { id: "Pfad_344", "data-name": "Pfad 344", d: "M273.094,106.394v4.06l-3.514-2.03v-4.06Z", transform: "translate(0 -13.516)", fill: "#f0f0f0" }), _jsx("path", { id: "Pfad_345", "data-name": "Pfad 345", d: "M276.608,100.988l-3.514,2.03-3.514-2.03,3.514-2.03Z", transform: "translate(0 -10.141)", fill: "#fff" }), _jsx("path", { id: "Pfad_346", "data-name": "Pfad 346", d: "M310.5,92.185l-3.514,2.03v-4.06l3.514-2.03Z", transform: "translate(-23.355 -3.377)", fill: "#f0f0f0" }), _jsx("path", { id: "Pfad_347", "data-name": "Pfad 347", d: "M304.657,84.747l-3.514,2.03-3.514-2.03,3.514-2.03Z", transform: "translate(-17.515)", fill: "#fff" }), _jsx("path", { id: "Pfad_348", "data-name": "Pfad 348", d: "M319.853,100.968l-3.514-2.03V103l3.514,2.03Z", transform: "translate(-29.198 -10.129)", fill: "#f0f0f0" }), _jsx("path", { id: "Pfad_349", "data-name": "Pfad 349", d: "M314.011,111.778l-3.514-2.03-3.514,2.03,3.514,2.03Z", transform: "translate(-23.356 -16.879)", fill: "#fff" })] }) })) : (footerIcon || icon.add), children: buttonText })] })] })] }));
};
export default FormFooter;
//# sourceMappingURL=FormFooter.js.map