import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import AddIcon from "@mui/icons-material/Add";
import { Box } from "@mui/material";
import Tooltip from "@mui/material/Tooltip";
import { FaChevronDown } from "@react-icons/all-files/fa/FaChevronDown";
import { FaChevronUp } from "@react-icons/all-files/fa/FaChevronUp";
import { FaTrashAlt } from "@react-icons/all-files/fa/FaTrashAlt";
import cx from "classnames";
import { useContext, useEffect, useState } from "react";
import { FormDataContext } from "../../context/FormData";
import HeaderCollapseButton from "../../ui-helper/HeaderCollapseButton";
import findFormControlError from "../../utils/findFormControlError";
import * as formBuilderStyles from "../FormBuilder/FormBuilder.module.scss";
import QueryControl from "../QueryControl";
import * as styles from "./FormList.module.scss";
const FormList = ({ ...props }) => {
    const { id, control, objectPathId, groupIsRequired, controlProps } = props;
    const { addListItem, removeListItem, moveListItemUp, moveListItemDown } = useContext(FormDataContext);
    const { "custom-attributes": customAttributes, displayName, items, error, template, required, } = control;
    const itemsLength = items?.length ?? 0;
    const defaultCollapseThreshold = Number(customAttributes?.defaultCollapseThreshold);
    const hasError = items?.some((item) => findFormControlError(item)) || error;
    const isClosed = itemsLength === 0 || defaultCollapseThreshold <= itemsLength;
    const [isOpen, setIsOpen] = useState(!isClosed);
    useEffect(() => {
        if (hasError)
            setIsOpen(true); //* list is always open if there is an error
    }, [isOpen, isClosed]);
    const handleToggleOpenState = () => setIsOpen((prev) => !prev);
    const handleAddItem = () => {
        addListItem(currObjectPathId);
        setIsOpen(true);
    };
    const currObjectPathId = objectPathId || id;
    const longList = template && Object.entries(template).length > 1;
    const displayNameWithRequired = required ? displayName + " *" : displayName;
    const className = longList
        ? "form-list-multiple-items"
        : "form-list-single-item";
    const firstControlTitle = !longList && template && Object.values(template)?.[0]?.displayName;
    const title = firstControlTitle || displayNameWithRequired || "";
    const mapControls = (key, configItem, listIndex) => {
        const index = listIndex || 0;
        const objectPathId = `${currObjectPathId}.items.[${index}].${key}`;
        return (_jsx(QueryControl, { formControl: configItem, id: key, objectPathId: objectPathId, hideLabel: !longList, groupIsRequired: groupIsRequired, controlProps: controlProps }, objectPathId));
    };
    const listStyle = controlProps?.listProps?.style ?? {};
    const listLabelStyle = controlProps?.listProps?.label?.style ?? {};
    const listContainerStyle = controlProps?.listProps?.container?.style ?? {};
    const listAddButtonStyle = controlProps?.listProps?.addButton?.sx ?? {};
    const controlTooltip = control?.["custom-attributes"]?.tooltip;
    const isHiddenList = !isOpen
        ? { display: "none", visibility: "hidden" }
        : {};
    return (_jsxs("div", { className: styles["list-container"], "data-testid": "form-list", style: listStyle, children: [_jsxs("div", { className: styles["list-header"], children: [_jsxs("div", { className: styles["list-header-label-button"], children: [_jsxs("div", { className: styles["list-header-label"], children: [_jsx("label", { "data-testid": "list-control-label", className: styles["list-label"], style: listLabelStyle, children: displayNameWithRequired }), controlTooltip && (_jsx(Tooltip, { title: controlTooltip, arrow: true, children: _jsx("span", { children: _jsx("i", { className: "fas fa-info-circle fa-xs" }) }) }))] }), _jsxs(Box, { "data-testid": title, className: cx("formbuilder_add-button", formBuilderStyles["xhtml-form-button"]), role: "alert", onClick: handleAddItem, sx: listAddButtonStyle, children: [_jsx(AddIcon, { sx: { fontSize: 20 }, "data-testid": "form-list__add-icon" }), "\u00A0", title] })] }), _jsx(HeaderCollapseButton, { itemsCount: itemsLength, isOpen: isOpen, onClick: handleToggleOpenState })] }), _jsx("div", { id: className, "data-testid": "form-list-children", role: "list", className: cx(styles[className], styles["list-children-container"]), "data-title": title, style: { ...isHiddenList, ...listContainerStyle }, children: items?.map((item, i) => {
                    if (!item)
                        return null;
                    const isLast = i === items.length - 1;
                    const isFirst = i === 0;
                    const sortableItems = items.length > 1;
                    return (_jsxs("div", { className: styles["form-list"], "data-testid": "form-list-child-element", role: "listitem", "data-is-filled": true, children: [item &&
                                Object.entries(item)?.map(([key, value]) => mapControls(key, value, i)), _jsx("button", { type: "button", className: cx(formBuilderStyles["xhtml-form-button"], formBuilderStyles["remove-item"], styles["remove-item"]), "data-testid": "form-list__remove-list-item-button", onClick: () => removeListItem(currObjectPathId, i), children: _jsx(FaTrashAlt, {}) }), _jsxs("div", { className: styles["sort-buttons"], children: [_jsx("button", { type: "button", onClick: () => moveListItemUp(currObjectPathId, i), disabled: isFirst || !sortableItems, children: _jsx(FaChevronUp, { "data-testid": "form-list__sort-up-button" }) }), _jsx("button", { type: "button", onClick: () => moveListItemDown(currObjectPathId, i), disabled: isLast || !sortableItems, children: _jsx(FaChevronDown, { "data-testid": "form-list__sort-down-button" }) })] })] }, `${objectPathId}-${i}`));
                }) })] }, id));
};
export default FormList;
//# sourceMappingURL=FormList.js.map