import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import omit from "lodash/omit";
import useInputDependent from "../../hooks/useDependent/enhanced/useInputDependent/useInputDependent";
import * as formControlStyles from "../../styles/formControl.module.scss";
import * as inputStyles from "./Input.module.scss";
import { StyledClearButton, StyledClearButtonWrapper, StyledInputWrapper, } from "./input.styles";
const Input = ({ onChangeValue, hasClearButton = false, onClearCallback, controlProps, ...props }) => {
    const { control, id, objectPathId, ...restProps } = props;
    const { value = "", displayName, "custom-attributes": customAttributes, error, placeholder, required, hasEdited, ...restControl } = control;
    const query = customAttributes?.defaultValue;
    const { textColor } = useInputDependent({
        onChangeValue,
        query,
        objectPathId,
        value,
        hasEdited,
    });
    const errorClass = error ? "error" : "";
    let className = formControlStyles["form-control"];
    className = errorClass
        ? className + " " + inputStyles[errorClass]
        : className;
    const requiredPlaceholder = placeholder
        ? required
            ? placeholder + " *"
            : placeholder
        : "";
    const handleOnChange = (e) => {
        onChangeValue({ value: e.target.value, hasEdited: "edited" });
    };
    const handleOnClear = () => {
        onChangeValue({ value: "" });
        onClearCallback?.();
    };
    const preventDefaultWheel = (e) => {
        const element = e.target;
        if (element.type === "number")
            element.blur();
    };
    return (_jsxs(StyledInputWrapper, { children: [_jsx("input", { role: "textbox", "data-testid": `input-control-${id}`, max: control.type === "date" ? "9999-12-31" : null, className: className, id: objectPathId || id, name: objectPathId || id, value: value, onChange: handleOnChange, onWheel: preventDefaultWheel, placeholder: requiredPlaceholder, required: required, ...omit(customAttributes, [
                    "defaultValue",
                    "mrnPreview",
                    "mrnSources",
                ]), ...omit(restControl, [
                    "displayName",
                    "placholder",
                    "control",
                    "error",
                    "defaultValue",
                ]), ...omit(restProps, ["defaultValue", "mrnPreview", "mrnSources"]), style: {
                    color: textColor,
                    minWidth: hasClearButton ? "175px" : "",
                    ...controlProps?.inputProps?.style,
                } }), hasClearButton && control.type === "date" && (_jsx(StyledClearButtonWrapper, { inputValue: value, children: _jsx(StyledClearButton, { "data-testid": "input_clearButton", fontSize: "small", onClick: handleOnClear }) }))] }));
};
export default Input;
//# sourceMappingURL=Input.js.map