import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import Autocomplete from "@mui/material/Autocomplete";
import Box from "@mui/material/Box";
import Tooltip from "@mui/material/Tooltip";
import omit from "lodash/omit";
import useInputDependent from "../../hooks/useDependent/enhanced/useInputDependent/useInputDependent";
import TextField from "../../styles/Textfield.styles";
import * as styles from "./InputFreeSolo.module.scss";
const InputFreeSolo = ({ ...props }) => {
    const { id, control, onChangeValue, objectPathId } = props;
    const { value = "", "custom-attributes": customAttributes, error, hasEdited, ...restControl } = control;
    const { options } = customAttributes;
    const errorClass = error ? "error" : "";
    const mappedOption = options.map((opt) => ({
        label: opt.text || opt.value,
        value: opt.value,
        tooltip: opt.tooltip,
        default: opt.default,
    }));
    let defaultValue = mappedOption.find((option) => option.value === value) || {
        label: value,
        value: value,
    };
    if (value === "") {
        const defaultOption = mappedOption.find((option) => option.default);
        if (defaultOption) {
            defaultValue = defaultOption;
        }
    }
    const clearStylesActive = restControl.type === "number" || restControl.type === "date";
    const currObjectPathId = objectPathId || id;
    const query = customAttributes?.defaultValue;
    const { textColor } = useInputDependent({
        onChangeValue,
        query,
        objectPathId: currObjectPathId,
        value,
        hasEdited,
    });
    const handleOnChange = (option) => {
        onChangeValue({ value: option, hasEdited: "edited" });
    };
    const preventDefaultWheel = (e) => {
        const element = e.target;
        if (element.type === "number")
            element.blur();
    };
    return (_jsx(Autocomplete, { className: `${styles["form-control"]}`, freeSolo: true, id: id, value: defaultValue, inputValue: value, options: mappedOption, readOnly: customAttributes?.readOnly, size: "small", onInputChange: (e, option) => handleOnChange(option), getOptionLabel: (option) => option.value || "", renderOption: (props, option) => (_jsx(Box, { component: "li", ...props, children: _jsxs("div", { className: styles.boxContainer, children: [_jsx("p", { children: option.label }), option.tooltip && (_jsx(Tooltip, { title: option.tooltip, arrow: true, children: _jsx("span", { children: _jsx("i", { className: "fas fa-info-circle fa-xs" }) }) }))] }) })), renderInput: (params) => (_jsx(TextField, { ...params, className: styles[errorClass], variant: "outlined", ...omit(restControl, [
                "displayName",
                "control",
                "error",
                "defaultValue",
            ]), ...omit(customAttributes, ["defaultValue"]), inputProps: { ...params.inputProps }, onWheel: preventDefaultWheel, sx: {
                "& input": {
                    color: textColor,
                    "&::-webkit-outer-spin-button, &::-webkit-inner-spin-button": {
                        "-webkit-appearance": "none",
                        margin: 0,
                    },
                },
                "& .MuiAutocomplete-endAdornment": {
                    right: clearStylesActive ? "35px !important" : "9px",
                },
            } })) }));
};
export default InputFreeSolo;
//# sourceMappingURL=InputFreeSolo.js.map