import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import Autocomplete from "@mui/material/Autocomplete";
import CircularProgress from "@mui/material/CircularProgress";
import uniqueId from "lodash/uniqueId";
import useInputDependent from "../../hooks/useDependent/enhanced/useInputDependent/useInputDependent";
import TextField from "../../styles/Textfield.styles";
import Select from "../Select";
import * as styles from "./MrnInput.module.scss";
import useMrn from "./hooks/useMrn";
import Link from "./ui-helper/Link/Link";
function customizer(option, key) {
    if (key === "mrnEntries") {
        return option?.mrnEntries;
    }
}
const MrnInput = ({ onChangeValue, controlProps, objectPathId, ...props }) => {
    const { id, control } = props || {};
    const { value = "", "custom-attributes": customAttributes, displayName, error, hasEdited, } = control || {};
    const errorClass = error ? "error" : "";
    const query = customAttributes?.defaultValue;
    const { isLoading, isOpen, isDisabled, mrnOptions, selectedOption, setSelectedOption, setSearchText, setIsOpen, currentMrnOption, onChangeCurrentMrnOption, } = useMrn({ value, customAttributes, objectPathId, onChangeValue });
    const { textColor } = useInputDependent({
        onChangeValue,
        query,
        objectPathId,
        value,
        hasEdited,
    });
    const mrnSourcesLength = customAttributes?.mrnSources?.length || 1;
    const handleChangeSelectedOption = (option) => {
        onChangeValue({
            hasEdited: "edited",
            value: option?.mrn || "",
            mrnEntries: option?.mrnEntries || null,
        }, (_objValue, _srcValue, key) => customizer(option, key));
        setSelectedOption(option);
    };
    const handleOnChange = (event) => {
        setSearchText(event?.target?.value);
    };
    const classes = mrnSourcesLength > 1 ? styles["with-select"] : "";
    return (_jsxs("div", { className: `${styles["mrn-input-container"]} ${classes}`, "data-testid": `mrn-input-container ${id}`, style: { color: textColor }, children: [mrnSourcesLength > 1 && (_jsx("div", { style: { width: "35%", height: "40px" }, children: _jsx(Select, { id: uniqueId(), control: {
                        control: "select",
                        options: customAttributes?.mrnSources?.map((source) => ({
                            value: source?.mrn,
                            text: source?.name,
                            ...source,
                        })),
                        value: currentMrnOption?.mrn,
                    }, controlProps: controlProps, onChangeValue: onChangeCurrentMrnOption }) })), _jsx(Autocomplete, { id: id, sx: {
                    width: "100%",
                    backgroundColor: "white",
                    ...controlProps?.selectProps?.sx,
                }, "data-testid": `mrn-input ${id}`, size: "small", value: selectedOption, readOnly: customAttributes?.readOnly, disabled: value ? false : isDisabled, onChange: (e, option) => handleChangeSelectedOption(option), isOptionEqualToValue: (option, optionValue) => option?.mrn === optionValue?.mrn, filterOptions: (options, state) => options, getOptionLabel: (option) => option?.key, options: mrnOptions, open: isOpen, onOpen: () => setIsOpen(true), onClose: () => setIsOpen(false), loading: isLoading, PaperComponent: (paperProps) => Link(paperProps.children, currentMrnOption?.["mrn-ref"] || currentMrnOption?.mrn, currentMrnOption?.name || displayName, controlProps?.mrnProps?.disableMrnLink, paperProps), renderInput: (params) => (_jsx(TextField, { ...params, className: styles[errorClass], onChange: handleOnChange, required: customAttributes?.required, sx: controlProps?.selectProps?.textField?.sx, InputProps: {
                        style: {
                            minHeight: 40,
                            color: textColor,
                        },
                        ...params.InputProps,
                        endAdornment: (_jsxs(_Fragment, { children: [isLoading && (_jsx(CircularProgress, { style: { marginRight: 30 }, color: "inherit", size: 20 })), params.InputProps.endAdornment] })),
                    } })) })] }));
};
export default MrnInput;
//# sourceMappingURL=MrnInput.js.map