import { useContext, useEffect, useState } from "react";
import { useUpdateEffect } from "usehooks-ts";
import { FormDataContext } from "../../../context/FormData";
import useDependent from "../../../hooks/useDependent/useDependent";
import getSelectedOption from "../../Select/utils/getSelectedOption";
import fetchMrn from "../services/fetchMrn";
import { determineUrlSearchParams } from "../utils/urlSearchParam/urlSearchParam";
const useMrn = ({ value, customAttributes, objectPathId, onChangeValue, }) => {
    const { resolveUrl } = useContext(FormDataContext);
    if (!resolveUrl)
        throw new Error("resolveUrl Prop is not defined");
    const [isLoading, setIsLoading] = useState(false);
    const [isOpen, setIsOpen] = useState(false);
    const [mrnOptions, setMrnOptions] = useState([]);
    const [selectedOption, setSelectedOption] = useState(null);
    const [searchText, setSearchText] = useState("");
    const selectedMrnSource = customAttributes?.mrnSources?.find((source) => value?.includes(source?.mrn));
    const mrnWhenMrnSources = selectedMrnSource || customAttributes?.mrnSources?.[0];
    const initialMrnOption = mrnWhenMrnSources || customAttributes;
    const [currentMrnOption, setCurrentMrnOption] = useState(initialMrnOption);
    const currentMrnQuery = currentMrnOption?.["mrn-ref-params"] || currentMrnOption?.query;
    const { dependentControls, resolvedQuery, isDisabled } = useDependent({
        query: currentMrnQuery,
        objectPathId,
    });
    const mrn = currentMrnOption?.["mrn-ref"] || currentMrnOption?.mrn;
    useEffect(() => {
        let isMounted = true;
        setCurrentMrnOption(initialMrnOption); //* Reset the currentMrnOption when the mrnSources change -> necessary for rerenders in lists
        const fetchDefaultOption = async () => {
            const urlParams = determineUrlSearchParams(resolvedQuery);
            const fetchSelectedMrnOption = await fetchMrn(value, currentMrnOption, urlParams, resolveUrl);
            if (isMounted) {
                onChangeValue({ mrnEntries: fetchSelectedMrnOption?.[0]?.mrnEntries });
                setSelectedOption(fetchSelectedMrnOption?.[0]);
            }
        };
        value ? fetchDefaultOption() : setSelectedOption(null);
        return () => {
            isMounted = false;
        };
    }, [value]);
    const handleChangeCurrentMrnOption = (newSource) => {
        const selectedValue = getSelectedOption(customAttributes?.mrnSources?.map((source) => ({
            value: source?.mrn,
            text: source?.name,
            ...source,
        })), newSource?.value);
        setCurrentMrnOption(selectedValue);
        setMrnOptions([]);
    };
    useUpdateEffect(() => {
        const timer = setTimeout(() => {
            handleTriggerSearch(searchText);
        }, 500);
        return () => clearTimeout(timer);
    }, [searchText]);
    const handleTriggerSearch = async (searchText) => {
        setIsLoading(true);
        setMrnOptions([]);
        const urlParams = determineUrlSearchParams(resolvedQuery, searchText);
        const filteredOptions = await fetchMrn(mrn, currentMrnOption, urlParams, resolveUrl);
        setMrnOptions(filteredOptions);
        setIsLoading(false);
    };
    useEffect(() => {
        const fetchMrnOptions = async () => {
            setIsLoading(true);
            const urlParams = determineUrlSearchParams(resolvedQuery);
            const fetchedMrnOptions = await fetchMrn(mrn, currentMrnOption, urlParams, resolveUrl);
            setMrnOptions(fetchedMrnOptions);
            setIsLoading(false);
        };
        !isOpen && setIsLoading(false);
        isOpen && fetchMrnOptions();
    }, [isOpen]);
    return {
        isLoading,
        isOpen,
        isDisabled,
        mrnOptions,
        selectedOption,
        setSelectedOption,
        setSearchText,
        setIsOpen,
        currentMrnOption,
        onChangeCurrentMrnOption: handleChangeCurrentMrnOption,
        dependentControls,
    };
};
export default useMrn;
//# sourceMappingURL=useMrn.js.map