const fetchMrn = async (mrnRef, attributes, params, resolveUrl) => {
    const mrnDisplayField = attributes["mrn-ref-display-field"] || attributes.displayField || "name";
    const mrnField = attributes["mrn-ref-mrn-field"] || "_mrn" || attributes.mrnField;
    // handle response
    const json = await resolveUrl(mrnRef, params, {
        headers: {
            accept: "application/xhtml-form+json",
        },
    });
    const hasValues = !!(json?.items || json?.values);
    if (!json || !hasValues) {
        throw new Error("unable to handle response - json expected");
    }
    const items = json.items || [json];
    const selectedAttributes = items.map((item) => {
        const allMrnAttributesKeys = Object.keys(item?.values).filter((key) => !key.startsWith("_"));
        const allMrnAttributes = {};
        allMrnAttributesKeys.forEach((attributeKey) => {
            allMrnAttributes[attributeKey] = item.values[attributeKey];
        });
        return {
            key: item.values[mrnDisplayField],
            mrn: item.values[mrnField],
            mrnEntries: allMrnAttributes,
        };
    });
    return selectedAttributes;
};
export default fetchMrn;
//# sourceMappingURL=fetchMrn.js.map