import { jsx as _jsx } from "react/jsx-runtime";
import Autocomplete from "@mui/material/Autocomplete";
import { useEffect, useState, } from "react";
import TextField from "../../styles/Textfield.styles";
import * as styles from "./MultiSelect.module.scss";
import extractSelectedOptionValues from "./utils/extractSelectedOptionValues";
const getSelectedValue = (options) => {
    return options
        .map((option) => {
        if (option.selected)
            return option.value;
        return null;
    })
        .filter((x) => !!x);
};
const MultiSelect = ({ onChangeValue, controlProps, id, control }) => {
    const [selectionOptions, setSelectionOptions] = useState([]);
    const [selectedOptions, setSelectedOptions] = useState([]);
    const [inputValue, setInputValue] = useState("");
    const { options, error, "custom-attributes": customAttributes } = control;
    const errorClass = error ? "error" : "";
    const onSelect = (selectedOptions) => {
        const { optionValues, updatedOptions } = extractSelectedOptionValues(options, selectedOptions);
        onChangeValue({ options: updatedOptions, value: optionValues }, (_, srcValue) => Array.isArray(srcValue) ? srcValue : undefined);
    };
    useEffect(() => {
        const allOptions = options.map((opt) => ({
            label: opt.text,
            value: opt.value,
        }));
        const selectedOpts = options
            .filter((option) => option.selected)
            .map((opt) => ({ label: opt.text, value: opt.value }));
        setSelectionOptions(allOptions);
        determineSelectedOptions(selectedOpts);
        const selectedValues = getSelectedValue(options);
        onChangeValue({ value: selectedValues });
    }, []);
    const determineSelectedOptions = (optionList) => {
        onSelect(optionList);
        setSelectedOptions(optionList);
    };
    return (_jsx(Autocomplete, { multiple: true, className: styles["multi-select-container"], id: id, readOnly: customAttributes?.readOnly, "data-testid": "multiselect__container", size: "small", sx: controlProps?.selectProps?.sx, value: selectedOptions, onChange: (e, option) => determineSelectedOptions(option), isOptionEqualToValue: (option, value) => option.value === value.value, inputValue: inputValue, onInputChange: (e, newInputValue) => setInputValue(newInputValue), options: selectionOptions, getOptionLabel: (option) => option.label, ListboxProps: {
            sx: {
                "& .MuiAutocomplete-option": {
                    minHeight: "40px",
                },
                ...controlProps?.selectProps?.listBox?.sx,
            },
        }, renderInput: (params) => (_jsx(TextField, { ...params, className: styles[errorClass], variant: "outlined", sx: {
                "& .MuiInputBase-root": {
                    minHeight: "40px",
                    "& .MuiChip-root": {
                        maxWidth: "calc(100% - 50px)",
                    },
                },
                ...controlProps?.selectProps?.textField?.sx,
            } })) }));
};
export default MultiSelect;
//# sourceMappingURL=MultiSelect.js.map