import { Fragment as _Fragment, jsx as _jsx } from "react/jsx-runtime";
import get from "lodash/get";
import { useContext, useEffect, useState } from "react";
import { FormDataContext } from "../../context/FormData";
import useValueGeneratorWithContext from "../../hooks/useValueGenerator/useValueGenerator";
import ControlWrapper from "../ControlWrapper";
import { extractMrn } from "../MrnInput/utils/mrnUtils/mrnUtils";
import defaultControls from "./data/defaultControls";
import QueryControlWrapper from "./ui-helper/Wrapper";
import getHighestMatchingControl from "./utils/getMatchingControls";
import hideGroup from "./utils/hideGroup";
const QueryControl = ({ formControl, id, objectPathId, hideLabel = false, groupIsRequired = true, isInGroup = false, controlProps, }) => {
    const { control, required, "custom-attributes": customAttributes, hasChanged, } = formControl;
    const visibility = customAttributes?.visibility?.form;
    const hideOnCondition = typeof visibility === "object" && visibility?.hideOnCondition;
    const { value: isHiddenValue } = useValueGeneratorWithContext({
        query: hideOnCondition,
        objectPathId,
    });
    const isHidden = visibility === "hidden" || isHiddenValue;
    const isExpert = visibility === "expert";
    const [resolvedAggregationMrnValue, setResolvedAggregationMrnValue] = useState(null);
    const hasMrnAttribute = customAttributes?.["mrn-ref"] || customAttributes?.mrnSources;
    const isMrn = control === "input" && !!hasMrnAttribute && !customAttributes?.mrnPreview;
    const { resolveUrl, enableExpertMode, hasExpertMode, isExpertMode } = useContext(FormDataContext);
    const isHiddenExpertControl = isExpert && !isExpertMode;
    const hideControl = (isHidden || isHiddenExpertControl) && !required;
    const hideGroupControl = control === "group" && hideGroup(formControl.controls, isExpertMode);
    const hideMrn = isMrn && hideControl;
    const hideComponent = hideGroupControl || hideMrn;
    const valueGeneratorTemplate = customAttributes?.valueGenerator?.template;
    const { value, hasQuery } = useValueGeneratorWithContext({
        query: valueGeneratorTemplate,
        objectPathId,
    });
    if (hasQuery && !hasChanged) {
        formControl.value = value;
    }
    useEffect(() => {
        if (isExpert && !hasExpertMode)
            enableExpertMode();
        //* ~
        const getAggregationValue = async () => {
            const isAggregationValue = Boolean(customAttributes?.mrnPreview) &&
                Boolean(!customAttributes?.mrnSources);
            if (!isAggregationValue)
                return;
            const isMrn = extractMrn(formControl.value);
            if (!isMrn)
                return null;
            const aggregationResponse = await fetchAggregationMrnValue();
            const aggregationResponseValue = get(aggregationResponse.values, customAttributes?.mrnPreview?.displayField);
            const isAggregationValueEmpty = !aggregationResponseValue || aggregationResponseValue === "null";
            const aggregationValue = isAggregationValueEmpty
                ? "-"
                : aggregationResponseValue;
            setResolvedAggregationMrnValue(aggregationValue);
        };
        getAggregationValue();
    }, []);
    const fetchAggregationMrnValue = async () => {
        const response = await resolveUrl(formControl.value, null, {
            headers: {
                accept: "application/xhtml-form+json",
            },
        });
        return response;
    };
    if (hideComponent)
        return _jsx(_Fragment, {});
    const controlConfig = {
        id,
        objectPathId,
        control: formControl,
        groupIsRequired,
        isInGroup,
        isExpertMode,
    };
    const layoutControlsWithoutWrapper = ["group", "list"];
    const customControls = [];
    const matchingControl = getHighestMatchingControl(formControl, customControls, defaultControls, objectPathId);
    const Control = matchingControl.control;
    if (layoutControlsWithoutWrapper.includes(control)) {
        return (_jsx(QueryControlWrapper, { isHidden: hideControl, isExpert: isExpert, children: _jsx(Control, { controlProps: controlProps, ...controlConfig }) }));
    }
    return (_jsx(QueryControlWrapper, { isHidden: hideControl, children: _jsx(ControlWrapper, { Control: Control, config: {
                ...controlConfig,
                control: {
                    ...formControl,
                    value: resolvedAggregationMrnValue || formControl.value,
                },
            }, isExpert: isExpert, hideLabel: hideLabel, controlProps: controlProps }) }));
};
export default QueryControl;
//# sourceMappingURL=QueryControl.js.map