import { jsx as _jsx } from "react/jsx-runtime";
import Autocomplete from "@mui/material/Autocomplete";
import { useEffect, useState, } from "react";
import useOptionsGenerator from "../../hooks/useDependent/enhanced/useOptionsGenerator/useOptionsGenerator";
import TextField from "../../styles/Textfield.styles";
import * as styles from "./Select.module.scss";
import getSelectedOption from "./utils/getSelectedOption";
const Select = ({ onChangeValue, controlProps, ...props }) => {
    const { id, control, objectPathId } = props;
    const { error, options, placeholder, required, value, "custom-attributes": customAttributes, } = control;
    const errorClass = error ? "error" : "";
    const defaultOptions = getSelectedOption(options, value);
    const requiredPlaceholder = placeholder
        ? required
            ? placeholder + " *"
            : placeholder
        : "";
    const { options: generatedOptions } = useOptionsGenerator({
        controlKey: id,
        objectPathId,
        options,
        query: customAttributes?.optionsGenerator,
    });
    const [selectedOption, setSelectedOption] = useState(defaultOptions);
    const [inputValue, setInputValue] = useState("");
    const currObjectPathId = objectPathId || id;
    useEffect(() => {
        if (!value) {
            //* value is undefinded in backend
            const selectedOpt = getSelectedOption(options, value);
            determineSelectedOption({ option: selectedOpt });
        }
        if (value !== selectedOption?.value) {
            const selectedOpt = getSelectedOption(options, value);
            determineSelectedOption({ option: selectedOpt, hasChanged: false });
        }
    }, [value]);
    const determineSelectedOption = ({ option, hasChanged = true, }) => {
        setSelectedOption(option);
        onChangeValue({
            value: option?.value || "",
            options: [
                ...options?.map((opt) => ({
                    ...opt,
                    selected: opt.value === option?.value,
                })),
            ],
            hasChanged,
        });
    };
    return (_jsx(Autocomplete, { className: styles["select-container"], id: currObjectPathId, "data-testid": `select-container ${id}`, disableClearable: true, size: "small", sx: controlProps?.selectProps?.sx, value: selectedOption, readOnly: customAttributes?.readOnly, onChange: (e, option) => determineSelectedOption({ option }), isOptionEqualToValue: (option, value) => option.value === value.value, inputValue: inputValue, onInputChange: (e, newInputValue) => setInputValue(newInputValue), options: generatedOptions, getOptionLabel: (option) => option.text, ListboxProps: {
            sx: {
                "& .MuiAutocomplete-option": {
                    minHeight: "40px",
                },
                ...controlProps?.selectProps?.listBox?.sx,
            },
        }, renderInput: (params) => (_jsx(TextField, { ...params, className: styles[errorClass], placeholder: requiredPlaceholder, required: required, sx: {
                "& > div": { minWidth: "0 !important" },
                "& .MuiInputBase-root": {
                    height: "40px",
                },
                ...controlProps?.selectProps?.textField?.sx,
            } })) }));
};
export default Select;
//# sourceMappingURL=Select.js.map