import { jsx as _jsx } from "react/jsx-runtime";
import { useContext, useEffect, } from "react";
import { FormDataContext } from "../../context/FormData";
import useInputDependent from "../../hooks/useDependent/enhanced/useInputDependent/useInputDependent";
import * as styles from "./Textarea.module.scss";
import AiWrapper from "./aiWrapper";
import DefaultEditor from "./editors/Default";
import HtmlEditor from "./editors/Html";
import JsonEditor from "./editors/Json";
import MarkdownEditor from "./editors/Markdown";
import RichTextEditor from "./editors/Richtext";
const Textarea = ({ onChangeValue, ...props }) => {
    const { control, id, objectPathId } = props;
    const { value = "", "custom-attributes": customAttributes, error, hasEdited, } = control;
    const currObjectPathId = objectPathId || id;
    const errorClass = error ? "error" : "";
    const query = customAttributes?.defaultValue;
    const { textColor } = useInputDependent({
        onChangeValue,
        query,
        objectPathId,
        value,
        hasEdited,
    });
    const genAiPrompts = customAttributes?.genAiPrompts;
    const { toggleRerendered } = useContext(FormDataContext);
    const TYPE = control.type;
    const EDITOR_TYPE = customAttributes?.editor;
    const readOnly = customAttributes?.readOnly;
    useEffect(() => {
        onChangeValue({ value: value || "" });
    }, [toggleRerendered]);
    const renderEditor = () => {
        switch (EDITOR_TYPE) {
            case "richtext":
                return RichTextEditor;
            case "markdown":
                return MarkdownEditor;
            default:
                if (TYPE === "html") {
                    return HtmlEditor;
                }
                else if (TYPE === "json") {
                    return JsonEditor;
                }
                else {
                    return DefaultEditor;
                }
        }
    };
    const TextareaControl = renderEditor();
    return (_jsx("div", { className: `${styles.textarea} textarea-control`, "data-testid": `textarea-${currObjectPathId}`, children: _jsx("div", { className: styles.textareaWithBorder, children: _jsx(AiWrapper, { aiActions: genAiPrompts, inputControl: _jsx(TextareaControl, { control: control, errorClass: errorClass, textColor: textColor, value: value, onChangeValue: onChangeValue, onChange: onChangeValue, id: currObjectPathId, readOnly: readOnly }), AiResponseControl: TextareaControl, onAcceptAiResponse: onChangeValue, objectPathId: currObjectPathId }) }) }));
};
export default Textarea;
//# sourceMappingURL=Textarea.js.map