// hooks
import { useContext, useState } from "react";
// context
import { FormDataContext } from "../../../context/FormData";
const useAi = ({ onAcceptAiResponse }) => {
    const [aiResponse, setAiResponse] = useState(null);
    const [isLoading, setIsLoading] = useState(false);
    const [isError, setIsError] = useState({
        state: false,
        message: "",
        prompt: "",
        profile: "",
    });
    const [loadingActionIndex, setLoadingActionIndex] = useState(null);
    const { postGenAiMessage } = useContext(FormDataContext);
    const handleAiActionClick = async (prompt, profile, index) => {
        setIsLoading(true);
        setLoadingActionIndex(index);
        const response = await postGenAiMessage?.({ message: prompt, profile });
        if (response.status === "success") {
            setAiResponse(response);
            setIsError({
                state: false,
                message: "",
                prompt: "",
                profile: "",
            });
        }
        else {
            setIsError({
                state: true,
                message: response.message,
                profile,
                prompt,
            });
        }
        setIsLoading(false);
        setLoadingActionIndex(null);
    };
    const handleAccept = () => {
        onAcceptAiResponse({ value: aiResponse.message });
        setAiResponse(null);
    };
    const handleDiscard = () => {
        setAiResponse(null);
    };
    const handleBack = () => {
        setAiResponse(null);
        setIsError({
            state: false,
            message: "",
            prompt: "",
            profile: "",
        });
    };
    const handleRetry = async () => {
        if (isError.prompt) {
            await handleAiActionClick(isError.prompt, isError.profile, loadingActionIndex);
        }
    };
    return {
        aiResponse,
        isLoading,
        isError,
        loadingActionIndex,
        handleAiActionClick,
        handleAccept,
        handleDiscard,
        handleBack,
        handleRetry,
    };
};
export default useAi;
//# sourceMappingURL=useAi.js.map