import get from "lodash/get";
import { useContext } from "react";
import resolveNestedQueryLink from "../../components/MrnInput/utils/resolveNestedQueryLink/resolveNestedQueryLink";
import { FormDataContext } from "../../context/FormData";
const useDependent = ({ query, objectPathId }) => {
    let mrnEntriesLoaded = true;
    if (!query) {
        return {
            dependentControls: [],
            resolvedQuery: "",
            isDisabled: false,
            mrnEntriesLoaded,
        };
    }
    const { getControlByObjectPath } = useContext(FormDataContext);
    const dependentControls = [];
    let isDisabled = false;
    let currentDependentQuery = query;
    let hasDependentQuery = true;
    // loops over query till there is no dependent control
    while (hasDependentQuery) {
        // gets next dependent control path
        let queryValue = currentDependentQuery.match(/#{(.*?)\}/)?.[1];
        // if there is no dependent control left exit
        if (!queryValue) {
            hasDependentQuery = false;
            break;
        }
        // default attribute key
        let attributeKey = "value";
        // checks if there is a specific attribute key for mrns
        const isMrnAttributeQuery = queryValue.includes("@");
        if (isMrnAttributeQuery) {
            attributeKey = queryValue.split(".@")[1];
            queryValue = queryValue.replace(`.@${attributeKey}`, "");
        }
        // resolve groups in QueryValue
        const splittedQueryIdPaths = queryValue.split(".");
        let resolvedQueryValueWithControlPaths = queryValue;
        if (splittedQueryIdPaths.length > 1) {
            resolvedQueryValueWithControlPaths = splittedQueryIdPaths
                .map((query, index) => {
                if (!query.includes("[*]") &&
                    index !== splittedQueryIdPaths.length - 1) {
                    return `${query}.controls`;
                }
                else {
                    return query;
                }
            })
                .join(".");
        }
        // build control path to dependent control
        const resolvedQueryValue = resolveNestedQueryLink(objectPathId, resolvedQueryValueWithControlPaths);
        // gets dependent control
        const dependentControl = getControlByObjectPath(resolvedQueryValue);
        // check if dependent control has value
        const isDepenentControlFilled = dependentControl?.value;
        if (!isDepenentControlFilled)
            isDisabled = true;
        // gets dependent control value
        let dependentControlValue = isMrnAttributeQuery
            ? get(dependentControl?.mrnEntries, attributeKey)
            : dependentControl?.value;
        // break if value is empty
        if (!dependentControlValue) {
            dependentControlValue = "";
            // edge case for mrn input with value but no mrnEntries
            if (dependentControl?.value && !dependentControl?.mrnEntries) {
                mrnEntriesLoaded = false;
            }
        }
        const dependentControlDisplayName = dependentControl?.displayName;
        dependentControls.push(dependentControlDisplayName);
        // replace query regex part in current query
        currentDependentQuery = currentDependentQuery.replace(`#{${isMrnAttributeQuery ? `${queryValue}.@${attributeKey}` : queryValue}}`, dependentControlValue);
    }
    return {
        dependentControls,
        resolvedQuery: currentDependentQuery,
        isDisabled,
        mrnEntriesLoaded,
    };
};
export default useDependent;
//# sourceMappingURL=useDependent.js.map