import { useContext } from "react";
import extractFormControlValues from "../../components/FormBuilder/utils/extractFormControlValues";
import getSelectedOption from "../../components/Select/utils/getSelectedOption";
import { FormDataContext, getControlByPath } from "../../context/FormData";
const REGEX_QUERY_CONTROL_PATH = /(\$|_)(\.[\w]+)+(?!\w*\()/g;
const useValueGenerator = ({ query, formControls, objectPathId, }) => {
    try {
        if (!query)
            return { value: "", hasQuery: false };
        let currentDependentQuery = query;
        let hasDependentQuery = true;
        while (hasDependentQuery) {
            const queryControlPath = currentDependentQuery.match(REGEX_QUERY_CONTROL_PATH)?.[0];
            if (!queryControlPath) {
                hasDependentQuery = false;
                break;
            }
            const splittedQueryControlPath = queryControlPath.split(".");
            const queryControlPathWithoutOperator = splittedQueryControlPath
                .slice(1)
                .join(".");
            const splittedQueryControlPathWithoutOperator = queryControlPathWithoutOperator.split(".");
            // add controls path for group controls to query
            let queryControlPathWithoutOperatorWithControls = splittedQueryControlPathWithoutOperator
                .map((query, index) => {
                if (index !== splittedQueryControlPathWithoutOperator.length - 1) {
                    return `${query}.controls`;
                }
                else {
                    return query;
                }
            })
                .join(".");
            if (queryControlPath.includes("$.")) {
                if (objectPathId?.includes(".")) {
                    queryControlPathWithoutOperatorWithControls = `${objectPathId
                        .split(".")
                        .slice(0, -1)
                        .join(".")}.${queryControlPathWithoutOperatorWithControls}`;
                }
            }
            // get control value
            const control = getControlByPath(formControls, queryControlPathWithoutOperatorWithControls.trim());
            if (!control)
                return { value: "", hasQuery: false };
            const isList = control?.control === "list";
            const isGroup = control?.control === "group";
            const isSelect = control?.control === "select";
            let controlValue;
            if (isList) {
                controlValue = control.items;
            }
            else if (isGroup) {
                controlValue = control.controls;
            }
            else {
                controlValue = control.value;
            }
            if (isList) {
                controlValue = JSON.stringify(extractFormControlValues({ key: control }).key);
            }
            else if (isSelect && !controlValue) {
                controlValue = getSelectedOption(control.options, "")?.value;
            }
            // controlValue can be a number or string
            const isNumber = control?.control === "input" && control?.type === "number";
            if (!isNumber && !isList && controlValue) {
                controlValue = `"${controlValue}"`;
            }
            if (!controlValue) {
                controlValue = "''";
            }
            // replace query with control value
            currentDependentQuery = currentDependentQuery.replace(queryControlPath.trim(), controlValue);
        }
        // eslint-disable-next-line no-eval
        const value = eval(currentDependentQuery);
        return { value, hasQuery: true };
    }
    catch (error) {
        console.error("Error in useValueGenerator", error);
        return { value: "", hasQuery: false };
    }
};
const useValueGeneratorWithContext = ({ query, objectPathId, }) => {
    try {
        if (!query)
            return { value: "", hasQuery: false };
        const { formControls } = useContext(FormDataContext);
        return useValueGenerator({ query, formControls, objectPathId });
    }
    catch (error) {
        console.error("Error in useValueGenerator", error);
        return { value: "", hasQuery: false };
    }
};
export { useValueGenerator, useValueGeneratorWithContext };
export default useValueGeneratorWithContext;
//# sourceMappingURL=useValueGenerator.js.map