import set from "lodash/set";
import hasExpertControl from "../../../../components/QueryControl/utils/hasExpertControl";
import hideGroup from "../../../../components/QueryControl/utils/hideGroup";
import useValueGeneratorWithContext from "../../../../hooks/useValueGenerator/useValueGenerator";
import findFormControlError from "../../../../utils/findFormControlError";
export const INFORMATION_TAB_KEY = "0";
export const INFO_MENU_ITEM = {
    name: "Info",
    icon: "fa-solid fa-circle-info",
};
const hasSubmenu = (control, isExpertMode) => {
    const customAttributes = control?.["custom-attributes"];
    const isGroup = control?.control === "group";
    const formVisibility = customAttributes?.visibility?.form;
    const hideOnCondition = typeof formVisibility === "object" && formVisibility?.hideOnCondition;
    const { value: hideOnConditionValue } = useValueGeneratorWithContext({
        query: hideOnCondition,
        objectPathId: "",
    });
    const isHidden = formVisibility === "hidden" ||
        (formVisibility === "expert" && !isExpertMode) ||
        hideOnConditionValue;
    const hasSubmenu = customAttributes?.submenu;
    return isGroup && hasSubmenu && !isHidden;
};
export const hasControlWithSubmenu = (controls, isExpertMode) => {
    return Object.values(controls).some((control) => hasSubmenu(control, isExpertMode));
};
export const determineMenuTabIndexWithControlError = (controlGroups) => {
    let index = INFORMATION_TAB_KEY;
    for (const [idx, controls] of Object.entries(controlGroups)) {
        const hasError = findFormControlError(controls);
        if (hasError) {
            index = idx;
            break;
        }
    }
    return Number(index);
};
const extractSubmenuTabs = (controls, isExpertMode) => {
    const controlGroups = {
        [INFORMATION_TAB_KEY]: {},
    };
    const menuItems = [INFO_MENU_ITEM];
    for (const [key, control] of Object.entries(controls)) {
        const isGroup = control.control === "group";
        const customAttributes = control?.["custom-attributes"];
        const isExpert = customAttributes?.visibility?.form === "expert";
        if (hasSubmenu(control, isExpertMode)) {
            const hasExpertFormControl = isGroup && (hasExpertControl(control?.controls) || isExpert);
            const allControlsHiddenOrExpert = isGroup && hideGroup(control?.controls, isExpertMode);
            const allControlsHiddenOrExpertWithAtLeastOneExpert = allControlsHiddenOrExpert && hasExpertFormControl;
            const hasOnlyHiddenControls = allControlsHiddenOrExpert && !hasExpertFormControl;
            const submenu = customAttributes?.submenu;
            const lastKey = Object.keys(controlGroups).pop(); //* keys are stringified indexes
            const newKey = Number(lastKey) + 1;
            if (!allControlsHiddenOrExpertWithAtLeastOneExpert &&
                !hasOnlyHiddenControls) {
                set(controlGroups, `${newKey}.${key}`, control);
                menuItems.push({
                    name: control.displayName,
                    icon: submenu?.icon || "fa-solid fa-circle-ellipsis",
                });
            }
        }
        else {
            set(controlGroups, `${INFORMATION_TAB_KEY}.${key}`, control);
        }
    }
    return {
        controlGroups,
        menuItems,
    };
};
const determineSubmenuTabs = (controls, isExpertMode) => {
    if (hasControlWithSubmenu(controls, isExpertMode)) {
        return extractSubmenuTabs(controls, isExpertMode);
    }
    return controls;
};
export default determineSubmenuTabs;
//# sourceMappingURL=index.js.map